summaryrefslogtreecommitdiff
path: root/tests/helpers.py
diff options
context:
space:
mode:
authorNed Batchelder <ned@nedbatchelder.com>2015-08-20 13:44:11 -0400
committerNed Batchelder <ned@nedbatchelder.com>2015-08-20 13:44:11 -0400
commitd5a89ab843542f88544a0f55900093329ef6b85c (patch)
tree096e088a8193c4d3ecd96755f9f35793d2a0bb76 /tests/helpers.py
parent33d7789e8e6c15aae52cf3e36eecbd48f36e248e (diff)
downloadpython-coveragepy-git-d5a89ab843542f88544a0f55900093329ef6b85c.tar.gz
Fix 'filename' to be 'file name' in English.
Diffstat (limited to 'tests/helpers.py')
-rw-r--r--tests/helpers.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/helpers.py b/tests/helpers.py
index 3d6be141..aa094bc1 100644
--- a/tests/helpers.py
+++ b/tests/helpers.py
@@ -29,7 +29,7 @@ def run_command(cmd):
class CheckUniqueFilenames(object):
"""Asserts the uniqueness of filenames passed to a function."""
def __init__(self, wrapped):
self.filenames = set()
self.wrapped = wrapped
@@ -45,7 +45,7 @@ class CheckUniqueFilenames(object):
def wrapper(self, filename, *args, **kwargs):
"""The replacement method. Check that we don't have dupes."""
assert filename not in self.filenames, (
- "Filename %r passed to %r twice" % (filename, self.wrapped)
+ "File name %r passed to %r twice" % (filename, self.wrapped)
)
self.filenames.add(filename)
ret = self.wrapped(filename, *args, **kwargs)
@@ -29,7 +29,7 @@ def run_command(cmd):
class CheckUniqueFilenames(object):
- """Asserts the uniqueness of filenames passed to a function."""
+ """Asserts the uniqueness of file names passed to a function."""
def __init__(self, wrapped):
self.filenames = set()